==> kubernetes-1.34.3.tar.gz: kubernetes-1.34.3/staging/src/k8s.io/code-generator/examples/apiserver/apis/example/types.go <==
/*
Copyright 2015 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package example

import metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"

// +genclient
// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

// TestType is a top-level type. A client is created for it.
type TestType struct {
	metav1.TypeMeta
	// +optional
	metav1.ObjectMeta
	// +optional
	Status TestTypeStatus
}

// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

// TestTypeList is a top-level list type. The client methods for lists are automatically created.
// You are not supposed to create a separated client for this one.
type TestTypeList struct {
	metav1.TypeMeta
	// +optional
	metav1.ListMeta

	Items []TestType
}

type TestTypeStatus struct {
	Blah string
}

type Conversion struct {
	Identical MemoryIdentical
	Different MemoryDifferent
}
type MemoryIdentical struct {
	Items      *MemoryIdentical
	Properties map[string]MemoryIdentical
	AllOf      []MemoryIdentical
	Bool       bool
}
type MemoryDifferent struct {
	Items      *MemoryDifferent
	Properties map[string]MemoryDifferent
	AllOf      []MemoryDifferent
	Bool       bool // differs from external representation
}

==> kubernetes-1.35.1.tar.gz: kubernetes-1.35.1/staging/src/k8s.io/code-generator/examples/apiserver/apis/example/types.go <==
/*
Copyright 2015 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package example

import metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"

// +genclient
// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

// TestType is a top-level type. A client is created for it.
type TestType struct {
	metav1.TypeMeta
	// +optional
	metav1.ObjectMeta
	// +optional
	Status TestTypeStatus
}

// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

// TestTypeList is a top-level list type. The client methods for lists are automatically created.
// You are not supposed to create a separated client for this one.
type TestTypeList struct {
	metav1.TypeMeta
	// +optional
	metav1.ListMeta

	Items []TestType
}

type TestTypeStatus struct {
	Blah string
}

type Conversion struct {
	Identical MemoryIdentical
	Different MemoryDifferent
}
type MemoryIdentical struct {
	Items      *MemoryIdentical
	Properties map[string]MemoryIdentical
	AllOf      []MemoryIdentical
	Bool       bool
}
type MemoryDifferent struct {
	Items      *MemoryDifferent
	Properties map[string]MemoryDifferent
	AllOf      []MemoryDifferent
	Bool       bool // differs from external representation
}

type ConversionPrivate struct {
	PublicField  string
	privateField string
}

type ConversionCustomContainer struct {
	Slice   []ConversionCustom
	SliceP  []*ConversionCustom
	Map     map[string]ConversionCustom
	MapP    map[string]*ConversionCustom
	Struct  ConversionCustom
	StructP *ConversionCustom
}
type ConversionCustom struct {
	PublicField  string
	privateField string
}
